@@ -1,6 +1,6 @@
 package Class::Meta;
 
-# $Id: Meta.pm,v 1.63 2004/01/20 22:36:44 david Exp $
+# $Id: Meta.pm,v 1.68 2004/01/28 21:57:26 david Exp $
 
 =head1 NAME
 
@@ -8,6 +8,8 @@ Class::Meta - Class automation, introspection, and data validation
 
 =head1 SYNOPSIS
 
+Generate a class:
+
   package MyApp::Thingy;
   use strict;
   use Class::Meta;
@@ -42,6 +44,47 @@ Class::Meta - Class automation, introspection, and data validation
       $cm->build;
   }
 
+Then use the class:
+
+  use MyApp::Thingy;
+
+  my $thingy = MyApp::Thingy->new;
+  print "ID: ", $thingy->id, $/;
+  $thingy->name('Larry');
+  print "Name: ", $thingy->name, $/;
+  $thingy->age(42);
+  print "Age: ", $thingy->age, $/;
+
+Or make use of the introspection API:
+
+  use MyApp::Thingy;
+
+  my $class = MyApp::Thingy->my_class;
+  my $thingy;
+
+  print "Examining object of class ", $class->package, $/;
+
+  print "\nConstructors:\n";
+  for my $ctor ($class->constructors) {
+      print "  o ", $ctor->name, $/;
+      $thingy = $ctor->call;
+  }
+
+  print "\nAttributes:\n";
+  for my $attr ($class->attributes) {
+      print "  o ", $attr->name, " => ", $attr->get($thingy), $/;
+      if ($attr->authz >= Class::Meta::SET && $attr->type eq 'string') {
+          $attr->get($thingy, 'hey there!');
+          print "    Changed to: ", $attr->get($thingy) $/;
+      }
+  }
+
+  print "\nMethods:\n";
+  for my $meth ($class->methods) {
+      print "  o ", $meth->name, $/;
+      $meth->call($thingy);
+  }
+
 =head1 DESCRIPTION
 
 Class::Meta provides an interface for automating the creation of Perl classes
@@ -158,7 +201,7 @@ And finally, we tell Class::Meta to build the class. This is the point at
 which all constructors and accessor methods will be created in the class. In
 this case, these include the C<new()> constructor and a C<tail()> accessor for
 the "tail" attribute. And finally, Class::Meta will install another method,
-C<class()>. This method will return a Class::Meta::Class object that
+C<my_class()>. This method will return a Class::Meta::Class object that
 describes the class, and provides the complete introspection API.
 
 =back
@@ -333,7 +376,7 @@ Class::Meta-generated classes. Those classes are:
 =head3 L<Class::Meta::Class|Class::Meta::Class>
 
 Describes the class. Each Class::Meta-generated class has a single constructor
-object that can be retrieved by calling a class' C<class()> class
+object that can be retrieved by calling a class' C<my_class()> class
 method. Using the Class::Meta::Class object, you can get access to all of the
 other objects that describe the class. The relevant methods are:
 
@@ -398,11 +441,15 @@ Returns the name of the attribute's data type.
 
 Returns true if the attribute is required to have a value.
 
-=item call_set
+=item once
+
+Returns true if the attribute value can be set to a defined value only once.
+
+=item set
 
 Sets the value of an attribute on an object.
 
-=item call_get
+=item get
 
 Returns the value of an attribute on an object.
 
@@ -537,7 +584,7 @@ use Class::Meta::Method;
 ##############################################################################
 # Package Globals                                                            #
 ##############################################################################
-our $VERSION = "0.14";
+our $VERSION = "0.20";
 
 ##############################################################################
 # Private Package Globals
@@ -660,6 +707,16 @@ for this parameter. Required.
 The name of the attribute. The name must consist of only alphanumeric
 characters or "_". Required.
 
+=item required
+
+A boolean value indicating whether the attribute is required to have a value.
+Defaults to false.
+
+=item once
+
+A boolean value indicating whether the attribute can be set to a defined value
+only once. Defaults to false.
+
 =item label
 
 A label for the attribute. Generally used for displaying its name in a user
@@ -743,9 +800,9 @@ accessor, you'd specify it like this:
 
 =item context
 
-The context of the attribute. This indicates whether it's a class attribute
-or an object attribute. The possible values are
-defined by the following constants:
+The context of the attribute. This indicates whether it's a class attribute or
+an object attribute. The possible values are defined by the following
+constants:
 
 =over 4
 
@@ -850,7 +907,7 @@ provide the introspection API for the class being generated.
   $cm->build;
 
 Builds the class defined by the Class::Meta object, including the
-C<class()> class method, and all requisite constructors and accessors.
+C<my_class()> class method, and all requisite constructors and accessors.
 
 =cut
 
@@ -885,13 +942,22 @@ __END__
 
 =item *
 
-Allow attributes to get a new value once and only once.
+Make class attribute accessors behave as they do in Class::Data::Inheritable.
+
+=item *
+
+Modify class attribute accessors so that they are thread safe. This will
+involve sharing the attributes across threads, and locking them before
+changing their values. If they've also been made to behave as they do in
+Class::Data::Inheritable, we'll have to figure out a way to make it so that
+newly generated accessors for subclasses are shared between threads, too. This
+may not be easy.
 
 =back
 
 =head1 DISTRIBUTION INFORMATION
 
-This file was packaged with the Class-Meta-0.14 distribution.
+This file was packaged with the Class-Meta-0.20 distribution.
 
 =head1 BUGS
 
